Changelog
=========

0.1.3
-----
#. Make admin resilient in case admin_urls.py is not in settings.

0.1.2
-----
#. Fix bug where the twitter account name may be overridden.

0.1.1
-----
#. Fix serious bug where new feeds could not be added.

0.1
---
#. First release.

